<?php



if (!defined('_PS_VERSION_')) {
	exit;
}



class OpopopReusablePackaging extends Module
{


	public function __construct()
	{
		$this->name = 'opopopreusablepackaging';
		$this->tab = 'shipping_logistics';
		$this->version = '1.2.0';
		$this->author = 'L\'équipe Opopop';
		$this->need_instance = 0;
		$this->ps_versions_compliancy = [
			'min' => '1.6',
			'max' => '1.7.99',
		];
		$this->bootstrap = true;
		parent::__construct();
		$this->displayName = $this->l('Colis réutilisable Opopop');
		$this->description = $this->l('Proposez l\'option "Colis Réutilisable Opopop" à vos clients.');
		$this->confirmUninstall = $this->l('Êtes-vous sûr·e de vouloir désinstaller ?');
	}


	public function install()
	{
		if (Shop::isFeatureActive()) {
			Shop::setContext(Shop::CONTEXT_ALL);
		}
		return (
			parent::install() 
			&& $this->registerHook('displayOrderConfirmation')
			&& $this->registerHook('displayFooter')
			&& Configuration::updateValue('OPOPOP_PRODUCT_ID', True)
		);
	}


	public function uninstall()
	{
		return (
			parent::uninstall() 
			&& Configuration::deleteByName('OPOPOP_PRODUCT_ID')
		);
	}


	# Configuration page
	public function getContent() {

		$output = '';

		// this part is executed only when the form is submitted
		if (Tools::isSubmit('submit' . $this->name)) {
			// retrieve the value set by the user
			$configValue = (string) Tools::getValue('OPOPOP_PRODUCT_ID');
			// check that the value is valid
			if (empty($configValue) || !Validate::isInt($configValue)) {
				// invalid value, show an error
				$output = $this->displayError($this->l('Une ID de produit doit être un nombre.'));
			} else {
				// value is ok, update it and display a confirmation message
				Configuration::updateValue('OPOPOP_PRODUCT_ID', $configValue);
				$output = $this->displayConfirmation($this->l('Settings updated'));
			}
		}

		// display any message, then the form
		return $output . $this->displayForm();

	}


	public function displayForm() {

		// Init Fields form array
		$form = [
			'form' => [
				'legend' => [
					'title' => $this->l('Paramétrer Opopop'),
				],
				'input' => [
					[
						'type' => 'text',
						'label' => $this->l('ID du produit Opopop'),
						'name' => 'OPOPOP_PRODUCT_ID',
						'size' => 20,
						'required' => true,
						'desc' => "Pour proposer l'option Opopop, vous devez créer un produit (virtuel ou physique) appelé 'Emballage Opopop zéro-déchet'. Indiquez ici l'ID de ce produit.",
					],
				],
				'submit' => [
					'title' => $this->l('Save'),
					'class' => 'btn btn-default pull-right',
				],
			],
		];

		$helper = new HelperForm();

		// Module, token and currentIndex
		$helper->table = $this->table;
		$helper->name_controller = $this->name;
		$helper->token = Tools::getAdminTokenLite('AdminModules');
		$helper->currentIndex = AdminController::$currentIndex . '&' . http_build_query(['configure' => $this->name]);
		$helper->submit_action = 'submit' . $this->name;

		// Default language
		$helper->default_form_language = (int) Configuration::get('PS_LANG_DEFAULT');

		// Load current value into the form
		$helper->fields_value['OPOPOP_PRODUCT_ID'] = Tools::getValue('OPOPOP_PRODUCT_ID', Configuration::get('OPOPOP_PRODUCT_ID'));

		return $helper->generateForm([$form]);
	}


	public function hookDisplayFooter($params) {

		$product_id = Configuration::get('OPOPOP_PRODUCT_ID');
		$product = new Product($product_id);

		$this->context->smarty->assign(
			[
				'opopop_product_id' => $product_id,
				'opopop_product' => $product,
				'opopop_price' => $product->getPrice(),
			]
		);

		return $this->display(__FILE__, 'opopop_popin.tpl');		
	}

	public function hookDisplayOrderConfirmation($params) {
		$this->context->smarty->assign(
			[
				'opopop_product_id' => Configuration::get('OPOPOP_PRODUCT_ID'),
			]
		);
		return $this->display(__FILE__, 'opopop_gotodeposit.tpl');		
	}


}